==> pyobjc-framework-QTKit-2.5.1.tar.gz: pyobjc-framework-QTKit-2.5.1/PyObjCTest/test_qtkitdefines.py <==

from PyObjCTools.TestSupport import *
from QTKit import *

class TestQTKitDefines (TestCase):
    def testConstants(self):
        self.assertEqual(QTKIT_VERSION_7_0, 70000)
        self.assertEqual(QTKIT_VERSION_7_2, 70200)

        self.assertEqual(VideoMediaType, fourcc(b'vide'))
        self.assertEqual(SoundMediaType, fourcc(b'soun'))
        self.assertEqual(TextMediaType, fourcc(b'text'))
        self.assertEqual(BaseMediaType, fourcc(b'gnrc'))
        self.assertEqual(MPEGMediaType, fourcc(b'MPEG'))
        self.assertEqual(MusicMediaType, fourcc(b'musi'))
        self.assertEqual(TimeCodeMediaType, fourcc(b'tmcd'))
        self.assertEqual(SpriteMediaType, fourcc(b'sprt'))
        self.assertEqual(FlashMediaType, fourcc(b'flsh'))
        self.assertEqual(MovieMediaType, fourcc(b'moov'))
        self.assertEqual(TweenMediaType, fourcc(b'twen'))
        self.assertEqual(ThreeDeeMediaType, fourcc(b'qd3d'))
        self.assertEqual(SkinMediaType, fourcc(b'skin'))
        self.assertEqual(HandleDataHandlerSubType, fourcc(b'hndl'))
        self.assertEqual(PointerDataHandlerSubType, fourcc(b'ptr '))
        self.assertEqual(NullDataHandlerSubType, fourcc(b'null'))
        self.assertEqual(ResourceDataHandlerSubType, fourcc(b'rsrc'))
        self.assertEqual(URLDataHandlerSubType, fourcc(b'url '))
        self.assertEqual(AliasDataHandlerSubType, fourcc(b'alis'))
        self.assertEqual(WiredActionHandlerType, fourcc(b'wire'))
        self.assertEqual(kQTQuartzComposerMediaType, fourcc(b'qtz '))
        self.assertEqual(TimeCode64MediaType, fourcc(b'tc64'))

        self.assertEqual(kQTFileTypeAIFF, fourcc(b'AIFF'))
        self.assertEqual(kQTFileTypeAIFC, fourcc(b'AIFC'))
        self.assertEqual(kQTFileTypeDVC, fourcc(b'dvc!'))
        self.assertEqual(kQTFileTypeMIDI, fourcc(b'Midi'))
        self.assertEqual(kQTFileTypePicture, fourcc(b'PICT'))
        self.assertEqual(kQTFileTypeMovie, fourcc(b'MooV'))
        self.assertEqual(kQTFileTypeText, fourcc(b'TEXT'))
        self.assertEqual(kQTFileTypeWave, fourcc(b'WAVE'))
        self.assertEqual(kQTFileTypeSystemSevenSound, fourcc(b'sfil'))
        self.assertEqual(kQTFileTypeMuLaw, fourcc(b'ULAW'))
        self.assertEqual(kQTFileTypeAVI, fourcc(b'VfW '))
        self.assertEqual(kQTFileTypeSoundDesignerII, fourcc(b'Sd2f'))
        self.assertEqual(kQTFileTypeAudioCDTrack, fourcc(b'trak'))
        self.assertEqual(kQTFileTypePICS, fourcc(b'PICS'))
        self.assertEqual(kQTFileTypeGIF, fourcc(b'GIFf'))
        self.assertEqual(kQTFileTypePNG, fourcc(b'PNGf'))
        self.assertEqual(kQTFileTypeTIFF, fourcc(b'TIFF'))
        self.assertEqual(kQTFileTypePhotoShop, fourcc(b'8BPS'))
        self.assertEqual(kQTFileTypeSGIImage, fourcc(b'.SGI'))
        self.assertEqual(kQTFileTypeBMP, fourcc(b'BMPf'))
        self.assertEqual(kQTFileTypeJPEG, fourcc(b'JPEG'))
        self.assertEqual(kQTFileTypeJFIF, fourcc(b'JPEG'))
        self.assertEqual(kQTFileTypeMacPaint, fourcc(b'PNTG'))
        self.assertEqual(kQTFileTypeTargaImage, fourcc(b'TPIC'))
        self.assertEqual(kQTFileTypeQuickDrawGXPicture, fourcc(b'qdgx'))
        self.assertEqual(kQTFileTypeQuickTimeImage, fourcc(b'qtif'))
        self.assertEqual(kQTFileType3DMF, fourcc(b'3DMF'))
        self.assertEqual(kQTFileTypeFLC, fourcc(b'FLC '))
        self.assertEqual(kQTFileTypeFlash, fourcc(b'SWFL'))
        self.assertEqual(kQTFileTypeFlashPix, fourcc(b'FPix'))
        self.assertEqual(kQTFileTypeMP4, fourcc(b'mpg4'))
        self.assertEqual(kQTFileTypePDF, fourcc(b'PDF '))
        self.assertEqual(kQTFileType3GPP, fourcc(b'3gpp'))
        self.assertEqual(kQTFileTypeAMR, fourcc(b'amr '))
        self.assertEqual(kQTFileTypeSDV, fourcc(b'sdv '))
        self.assertEqual(kQTFileType3GP2, fourcc(b'3gp2'))
        self.assertEqual(kQTFileTypeAMC, fourcc(b'amc '))
        self.assertEqual(kQTFileTypeJPEG2000, fourcc(b'jp2 '))
        self.assertEqual(codecLosslessQuality, 0x00000400)
        self.assertEqual(codecMaxQuality, 0x000003FF)
        self.assertEqual(codecMinQuality, 0x00000000)
        self.assertEqual(codecLowQuality, 0x00000100)
        self.assertEqual(codecNormalQuality, 0x00000200)
        self.assertEqual(codecHighQuality, 0x00000300)
        self.assertEqual(kRawCodecType, fourcc(b'raw '))
        self.assertEqual(kCinepakCodecType, fourcc(b'cvid'))
        self.assertEqual(kGraphicsCodecType, fourcc(b'smc '))
        self.assertEqual(kAnimationCodecType, fourcc(b'rle '))
        self.assertEqual(kVideoCodecType, fourcc(b'rpza'))
        self.assertEqual(kComponentVideoCodecType, fourcc(b'yuv2'))
        self.assertEqual(kJPEGCodecType, fourcc(b'jpeg'))
        self.assertEqual(kMotionJPEGACodecType, fourcc(b'mjpa'))
        self.assertEqual(kMotionJPEGBCodecType, fourcc(b'mjpb'))
        self.assertEqual(kSGICodecType, fourcc(b'.SGI'))
        self.assertEqual(kPlanarRGBCodecType, fourcc(b'8BPS'))
        self.assertEqual(kMacPaintCodecType, fourcc(b'PNTG'))
        self.assertEqual(kGIFCodecType, fourcc(b'gif '))
        self.assertEqual(kPhotoCDCodecType, fourcc(b'kpcd'))
        self.assertEqual(kQuickDrawGXCodecType, fourcc(b'qdgx'))
        self.assertEqual(kAVRJPEGCodecType, fourcc(b'avr '))
        self.assertEqual(kOpenDMLJPEGCodecType, fourcc(b'dmb1'))
        self.assertEqual(kBMPCodecType, fourcc(b'WRLE'))
        self.assertEqual(kWindowsRawCodecType, fourcc(b'WRAW'))
        self.assertEqual(kVectorCodecType, fourcc(b'path'))
        self.assertEqual(kQuickDrawCodecType, fourcc(b'qdrw'))
        self.assertEqual(kWaterRippleCodecType, fourcc(b'ripl'))
        self.assertEqual(kFireCodecType, fourcc(b'fire'))
        self.assertEqual(kCloudCodecType, fourcc(b'clou'))
        self.assertEqual(kH261CodecType, fourcc(b'h261'))
        self.assertEqual(kH263CodecType, fourcc(b'h263'))
        self.assertEqual(kDVCNTSCCodecType, fourcc(b'dvc '))
        self.assertEqual(kDVCPALCodecType, fourcc(b'dvcp'))
        self.assertEqual(kDVCProPALCodecType, fourcc(b'dvpp'))
        self.assertEqual(kDVCPro50NTSCCodecType, fourcc(b'dv5n'))
        self.assertEqual(kDVCPro50PALCodecType, fourcc(b'dv5p'))
        #self.assertEqual(kDVCPro100NTSCCodecType, fourcc(b'dv1n'))
        self.assertEqual(kDVCPro100PALCodecType, fourcc(b'dv1p'))
        self.assertEqual(kDVCPROHD720pCodecType, fourcc(b'dvhp'))
        self.assertEqual(kDVCPROHD1080i60CodecType, fourcc(b'dvh6'))
        self.assertEqual(kDVCPROHD1080i50CodecType, fourcc(b'dvh5'))
        self.assertEqual(kBaseCodecType, fourcc(b'base'))
        self.assertEqual(kFLCCodecType, fourcc(b'flic'))
        self.assertEqual(kTargaCodecType, fourcc(b'tga '))
        self.assertEqual(kPNGCodecType, fourcc(b'png '))
        self.assertEqual(kTIFFCodecType, fourcc(b'tiff'))
        self.assertEqual(kComponentVideoSigned, fourcc(b'yuvu'))
        self.assertEqual(kComponentVideoUnsigned, fourcc(b'yuvs'))
        self.assertEqual(kCMYKCodecType, fourcc(b'cmyk'))
        self.assertEqual(kMicrosoftVideo1CodecType, fourcc(b'msvc'))
        self.assertEqual(kSorensonCodecType, fourcc(b'SVQ1'))
        self.assertEqual(kSorenson3CodecType, fourcc(b'SVQ3'))
        self.assertEqual(kIndeo4CodecType, fourcc(b'IV41'))
        self.assertEqual(kMPEG4VisualCodecType, fourcc(b'mp4v'))
        self.assertEqual(k64ARGBCodecType, fourcc(b'b64a'))
        self.assertEqual(k48RGBCodecType, fourcc(b'b48r'))
        self.assertEqual(k32AlphaGrayCodecType, fourcc(b'b32a'))
        self.assertEqual(k16GrayCodecType, fourcc(b'b16g'))
        self.assertEqual(kMpegYUV420CodecType, fourcc(b'myuv'))
        self.assertEqual(kYUV420CodecType, fourcc(b'y420'))
        self.assertEqual(kSorensonYUV9CodecType, fourcc(b'syv9'))
        self.assertEqual(k422YpCbCr8CodecType, fourcc(b'2vuy'))
        self.assertEqual(k444YpCbCr8CodecType, fourcc(b'v308'))
        self.assertEqual(k4444YpCbCrA8CodecType, fourcc(b'v408'))
        self.assertEqual(k422YpCbCr16CodecType, fourcc(b'v216'))
        self.assertEqual(k422YpCbCr10CodecType, fourcc(b'v210'))
        self.assertEqual(k444YpCbCr10CodecType, fourcc(b'v410'))
        self.assertEqual(k4444YpCbCrA8RCodecType, fourcc(b'r408'))
        self.assertEqual(kJPEG2000CodecType, fourcc(b'mjp2'))
        self.assertEqual(kPixletCodecType, fourcc(b'pxlt'))
        self.assertEqual(kH264CodecType, fourcc(b'avc1'))
        self.assertEqual(graphicsModeStraightAlpha, 256)
        self.assertEqual(graphicsModePreWhiteAlpha, 257)
        self.assertEqual(graphicsModePreBlackAlpha, 258)
        self.assertEqual(graphicsModeComposition, 259)
        self.assertEqual(graphicsModeStraightAlphaBlend, 260)
        self.assertEqual(graphicsModePreMulColorAlpha, 261)
        self.assertEqual(graphicsModePerComponentAlpha, 272)


if __name__ == "__main__":
    main()

==> pyobjc-framework-QTKit-5.3.tar.gz: pyobjc-framework-QTKit-5.3/PyObjCTest/test_qtkitdefines.py <==

from PyObjCTools.TestSupport import *
from QTKit import *

class TestQTKitDefines (TestCase):
    def testConstants(self):
        self.assertEqual(QTKIT_VERSION_7_0, 70000)
        self.assertEqual(QTKIT_VERSION_7_2, 70200)
        self.assertEqual(QTKIT_VERSION_7_6_3, 70603)
        self.assertEqual(QTKIT_VERSION_7_6_6, 70606)
        self.assertEqual(QTKIT_VERSION_7_7, 70700)
        self.assertEqual(QTKIT_VERSION_7_7_2, 70702)
        self.assertEqual(QTKIT_VERSION_7_7_3, 70703)


        self.assertEqual(VideoMediaType, fourcc(b'vide'))
        self.assertEqual(SoundMediaType, fourcc(b'soun'))
        self.assertEqual(TextMediaType, fourcc(b'text'))
        self.assertEqual(BaseMediaType, fourcc(b'gnrc'))
        self.assertEqual(MPEGMediaType, fourcc(b'MPEG'))
        self.assertEqual(MusicMediaType, fourcc(b'musi'))
        self.assertEqual(TimeCodeMediaType, fourcc(b'tmcd'))
        self.assertEqual(SpriteMediaType, fourcc(b'sprt'))
        self.assertEqual(FlashMediaType, fourcc(b'flsh'))
        self.assertEqual(MovieMediaType, fourcc(b'moov'))
        self.assertEqual(TweenMediaType, fourcc(b'twen'))
        self.assertEqual(ThreeDeeMediaType, fourcc(b'qd3d'))
        self.assertEqual(SkinMediaType, fourcc(b'skin'))
        self.assertEqual(HandleDataHandlerSubType, fourcc(b'hndl'))
        self.assertEqual(PointerDataHandlerSubType, fourcc(b'ptr '))
        self.assertEqual(NullDataHandlerSubType, fourcc(b'null'))
        self.assertEqual(ResourceDataHandlerSubType, fourcc(b'rsrc'))
        self.assertEqual(URLDataHandlerSubType, fourcc(b'url '))
        self.assertEqual(AliasDataHandlerSubType, fourcc(b'alis'))
        self.assertEqual(WiredActionHandlerType, fourcc(b'wire'))
        self.assertEqual(kQTQuartzComposerMediaType, fourcc(b'qtz '))
        self.assertEqual(TimeCode64MediaType, fourcc(b'tc64'))

        self.assertEqual(kQTFileTypeAIFF, fourcc(b'AIFF'))
        self.assertEqual(kQTFileTypeAIFC, fourcc(b'AIFC'))
        self.assertEqual(kQTFileTypeDVC, fourcc(b'dvc!'))
        self.assertEqual(kQTFileTypeMIDI, fourcc(b'Midi'))
        self.assertEqual(kQTFileTypePicture, fourcc(b'PICT'))
        self.assertEqual(kQTFileTypeMovie, fourcc(b'MooV'))
        self.assertEqual(kQTFileTypeText, fourcc(b'TEXT'))
        self.assertEqual(kQTFileTypeWave, fourcc(b'WAVE'))
        self.assertEqual(kQTFileTypeSystemSevenSound, fourcc(b'sfil'))
        self.assertEqual(kQTFileTypeMuLaw, fourcc(b'ULAW'))
        self.assertEqual(kQTFileTypeAVI, fourcc(b'VfW '))
        self.assertEqual(kQTFileTypeSoundDesignerII, fourcc(b'Sd2f'))
        self.assertEqual(kQTFileTypeAudioCDTrack, fourcc(b'trak'))
        self.assertEqual(kQTFileTypePICS, fourcc(b'PICS'))
        self.assertEqual(kQTFileTypeGIF, fourcc(b'GIFf'))
        self.assertEqual(kQTFileTypePNG, fourcc(b'PNGf'))
        self.assertEqual(kQTFileTypeTIFF, fourcc(b'TIFF'))
        self.assertEqual(kQTFileTypePhotoShop, fourcc(b'8BPS'))
        self.assertEqual(kQTFileTypeSGIImage, fourcc(b'.SGI'))
        self.assertEqual(kQTFileTypeBMP, fourcc(b'BMPf'))
        self.assertEqual(kQTFileTypeJPEG, fourcc(b'JPEG'))
        self.assertEqual(kQTFileTypeJFIF, fourcc(b'JPEG'))
        self.assertEqual(kQTFileTypeMacPaint, fourcc(b'PNTG'))
        self.assertEqual(kQTFileTypeTargaImage, fourcc(b'TPIC'))
        self.assertEqual(kQTFileTypeQuickDrawGXPicture, fourcc(b'qdgx'))
        self.assertEqual(kQTFileTypeQuickTimeImage, fourcc(b'qtif'))
        self.assertEqual(kQTFileType3DMF, fourcc(b'3DMF'))
        self.assertEqual(kQTFileTypeFLC, fourcc(b'FLC '))
        self.assertEqual(kQTFileTypeFlash, fourcc(b'SWFL'))
        self.assertEqual(kQTFileTypeFlashPix, fourcc(b'FPix'))
        self.assertEqual(kQTFileTypeMP4, fourcc(b'mpg4'))
        self.assertEqual(kQTFileTypePDF, fourcc(b'PDF '))
        self.assertEqual(kQTFileType3GPP, fourcc(b'3gpp'))
        self.assertEqual(kQTFileTypeAMR, fourcc(b'amr '))
        self.assertEqual(kQTFileTypeSDV, fourcc(b'sdv '))
        self.assertEqual(kQTFileType3GP2, fourcc(b'3gp2'))
        self.assertEqual(kQTFileTypeAMC, fourcc(b'amc '))
        self.assertEqual(kQTFileTypeJPEG2000, fourcc(b'jp2 '))
        self.assertEqual(codecLosslessQuality, 0x00000400)
        self.assertEqual(codecMaxQuality, 0x000003FF)
        self.assertEqual(codecMinQuality, 0x00000000)
        self.assertEqual(codecLowQuality, 0x00000100)
        self.assertEqual(codecNormalQuality, 0x00000200)
        self.assertEqual(codecHighQuality, 0x00000300)
        self.assertEqual(kRawCodecType, fourcc(b'raw '))
        self.assertEqual(kCinepakCodecType, fourcc(b'cvid'))
        self.assertEqual(kGraphicsCodecType, fourcc(b'smc '))
        self.assertEqual(kAnimationCodecType, fourcc(b'rle '))
        self.assertEqual(kVideoCodecType, fourcc(b'rpza'))
        self.assertEqual(kComponentVideoCodecType, fourcc(b'yuv2'))
        self.assertEqual(kJPEGCodecType, fourcc(b'jpeg'))
        self.assertEqual(kMotionJPEGACodecType, fourcc(b'mjpa'))
        self.assertEqual(kMotionJPEGBCodecType, fourcc(b'mjpb'))
        self.assertEqual(kSGICodecType, fourcc(b'.SGI'))
        self.assertEqual(kPlanarRGBCodecType, fourcc(b'8BPS'))
        self.assertEqual(kMacPaintCodecType, fourcc(b'PNTG'))
        self.assertEqual(kGIFCodecType, fourcc(b'gif '))
        self.assertEqual(kPhotoCDCodecType, fourcc(b'kpcd'))
        self.assertEqual(kQuickDrawGXCodecType, fourcc(b'qdgx'))
        self.assertEqual(kAVRJPEGCodecType, fourcc(b'avr '))
        self.assertEqual(kOpenDMLJPEGCodecType, fourcc(b'dmb1'))
        self.assertEqual(kBMPCodecType, fourcc(b'WRLE'))
        self.assertEqual(kWindowsRawCodecType, fourcc(b'WRAW'))
        self.assertEqual(kVectorCodecType, fourcc(b'path'))
        self.assertEqual(kQuickDrawCodecType, fourcc(b'qdrw'))
        self.assertEqual(kWaterRippleCodecType, fourcc(b'ripl'))
        self.assertEqual(kFireCodecType, fourcc(b'fire'))
        self.assertEqual(kCloudCodecType, fourcc(b'clou'))
        self.assertEqual(kH261CodecType, fourcc(b'h261'))
        self.assertEqual(kH263CodecType, fourcc(b'h263'))
        self.assertEqual(kDVCNTSCCodecType, fourcc(b'dvc '))
        self.assertEqual(kDVCPALCodecType, fourcc(b'dvcp'))
        self.assertEqual(kDVCProPALCodecType, fourcc(b'dvpp'))
        self.assertEqual(kDVCPro50NTSCCodecType, fourcc(b'dv5n'))
        self.assertEqual(kDVCPro50PALCodecType, fourcc(b'dv5p'))
        #self.assertEqual(kDVCPro100NTSCCodecType, fourcc(b'dv1n'))
        self.assertEqual(kDVCPro100PALCodecType, fourcc(b'dv1p'))
        self.assertEqual(kDVCPROHD720pCodecType, fourcc(b'dvhp'))
        self.assertEqual(kDVCPROHD1080i60CodecType, fourcc(b'dvh6'))
        self.assertEqual(kDVCPROHD1080i50CodecType, fourcc(b'dvh5'))
        self.assertEqual(kBaseCodecType, fourcc(b'base'))
        self.assertEqual(kFLCCodecType, fourcc(b'flic'))
        self.assertEqual(kTargaCodecType, fourcc(b'tga '))
        self.assertEqual(kPNGCodecType, fourcc(b'png '))
        self.assertEqual(kTIFFCodecType, fourcc(b'tiff'))
        self.assertEqual(kComponentVideoSigned, fourcc(b'yuvu'))
        self.assertEqual(kComponentVideoUnsigned, fourcc(b'yuvs'))
        self.assertEqual(kCMYKCodecType, fourcc(b'cmyk'))
        self.assertEqual(kMicrosoftVideo1CodecType, fourcc(b'msvc'))
        self.assertEqual(kSorensonCodecType, fourcc(b'SVQ1'))
        self.assertEqual(kSorenson3CodecType, fourcc(b'SVQ3'))
        self.assertEqual(kIndeo4CodecType, fourcc(b'IV41'))
        self.assertEqual(kMPEG4VisualCodecType, fourcc(b'mp4v'))
        self.assertEqual(k64ARGBCodecType, fourcc(b'b64a'))
        self.assertEqual(k48RGBCodecType, fourcc(b'b48r'))
        self.assertEqual(k32AlphaGrayCodecType, fourcc(b'b32a'))
        self.assertEqual(k16GrayCodecType, fourcc(b'b16g'))
        self.assertEqual(kMpegYUV420CodecType, fourcc(b'myuv'))
        self.assertEqual(kYUV420CodecType, fourcc(b'y420'))
        self.assertEqual(kSorensonYUV9CodecType, fourcc(b'syv9'))
        self.assertEqual(k422YpCbCr8CodecType, fourcc(b'2vuy'))
        self.assertEqual(k444YpCbCr8CodecType, fourcc(b'v308'))
        self.assertEqual(k4444YpCbCrA8CodecType, fourcc(b'v408'))
        self.assertEqual(k422YpCbCr16CodecType, fourcc(b'v216'))
        self.assertEqual(k422YpCbCr10CodecType, fourcc(b'v210'))
        self.assertEqual(k444YpCbCr10CodecType, fourcc(b'v410'))
        self.assertEqual(k4444YpCbCrA8RCodecType, fourcc(b'r408'))
        self.assertEqual(kJPEG2000CodecType, fourcc(b'mjp2'))
        self.assertEqual(kPixletCodecType, fourcc(b'pxlt'))
        self.assertEqual(kH264CodecType, fourcc(b'avc1'))
        self.assertEqual(graphicsModeStraightAlpha, 256)
        self.assertEqual(graphicsModePreWhiteAlpha, 257)
        self.assertEqual(graphicsModePreBlackAlpha, 258)
        self.assertEqual(graphicsModeComposition, 259)
        self.assertEqual(graphicsModeStraightAlphaBlend, 260)
        self.assertEqual(graphicsModePreMulColorAlpha, 261)
        self.assertEqual(graphicsModePerComponentAlpha, 272)


if __name__ == "__main__":
    main()
